Struct amazon_sp_reports::models::report_document::ReportDocument
source · [−]pub struct ReportDocument {
pub report_document_id: String,
pub url: String,
pub encryption_details: Box<ReportDocumentEncryptionDetails>,
pub compression_algorithm: Option<CompressionAlgorithm>,
}Fields
report_document_id: StringThe identifier for the report document. This identifier is unique only in combination with a seller ID.
url: StringA presigned URL for the report document. If compressionAlgorithm is not returned, you can download the report directly from this URL. This URL expires after 5 minutes.
encryption_details: Box<ReportDocumentEncryptionDetails>compression_algorithm: Option<CompressionAlgorithm>If the report document contents have been compressed, the compression algorithm used is returned in this property and you must decompress the report when you download. Otherwise, you can download the report directly. Refer to Step 2. Download and decrypt the report in the use case guide, where sample code is provided.
Implementations
sourceimpl ReportDocument
impl ReportDocument
pub fn new(
report_document_id: String,
url: String,
encryption_details: ReportDocumentEncryptionDetails
) -> ReportDocument